@@ -13,6 +13,10 @@
 
 namespace OCA\Bookmarks\AppInfo;
 
+if ((@include_once __DIR__ . '/../vendor/autoload.php')===false) {
+  throw new \Exception('Cannot include autoload. Did you run install dependencies using composer?');
+}
+
 $navigationEntry = function () {
 	return [
 		'id' => 'bookmarks',
