@@ -33,18 +33,22 @@ OC.L10N.register(
     "An error occurred while trying to save the bookmark." : "Při pokusu o uložení záložky nastala chyba.",
     "Error" : "Chyba",
     "Uploading..." : "Nahrávání",
-    "Import error" : "Import selhal",
+    "Import error" : "Import se nezdařil",
     "Import completed successfully." : "Import byl úspěšně dokončen",
     "Set tags" : "Nastavit štítky",
     "A Bookmark manager for Nextcloud" : "Správce záložek pro Nextcloud",
     "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tato aplikace vám umožní ukládat a organizovat vaše oblíbené stránky na internetu a zároveň je synchronizuje přes vaše zařízení a prohlížeče. Mrkněte na neoficiální klienty: https://github.com/nextcloud/bookmarks#third-party-clients",
     "Add a bookmark" : "Přidat do záložek",
-    "This URL is already bookmarked! Overwrite?" : "Adresa URL stánky je již v záložkách! Přepsat ?",
+    "This URL is already bookmarked! Overwrite?" : "Adresa URL stánky už je v záložkách! Přepsat ?",
     "The title of the page" : "Nadpis stránky",
     "The address of the page" : "Adresa stránky",
     "Description of the page" : "Popis stránky",
     "Save" : "Uložit",
     "Previews" : "Náhledy",
+    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Pro zobrazování skutečných snímků webových stránek v záložkách, aplikace Záložky může pro jejich vytváření používat službu třetí strany.",
+    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Můžete se buď zdarma přihlásit na <a href=\"http://screeenly.com\">screeenly.com</a> nebo <a href=\"https://github.com/stefanzweifel/screeenly\">si nastavit vlastní server</a>.",
+    "Screenly API URL" : "URL adresa aplikačního program. rozhraní služby Screenly",
+    "Screenly API key" : "Klíč k aplikačnímu program. rozhraní služby Screenly",
     "Bookmarks feed" : "Kanál záložek"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
