@@ -11,13 +11,17 @@ OC.L10N.register(
     "Deselect" : "Αποεπιλογή",
     "Details" : "Λεπτομέρειες",
     "Delete" : "Διαγραφή",
+    "Saved" : "Αποθηκεύτηκε",
     "Tags" : "Ετικέτες",
     "Description" : "Περιγραφή",
     "No bookmarks here." : "Δεν υπάρχουν σελιδοδείκτες εδώ",
     "All bookmarks" : "Όλοι οι σελιδοδείκτες",
     "Untagged" : "Χωρίς ετικέτα",
+    "Shared" : "Κοινόχρηστα",
     "Settings" : "Ρυθμίσεις",
+    "Add to {instanceName} " : "Προσθήκη στο {instanceName} ",
     "Recently added" : "Προστέθηκαν πρόσφατα",
+    "RSS Feed" : "Ροή RSS",
     "Add to filter" : "Προσθήκη στο φίλτρο",
     "Rename" : "Μετονομασία",
     "Open details" : "Άνοιγμα λεπτομερειών",
