@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Bookmarks" : "ブックマーク",
     "Failed to import one bookmark, because: " : "ブックマークのインポートに失敗しました。原因:",
+    "Add a Bookmark" : "ブックマークを追加",
+    "Select" : "選択",
     "Saved" : "保存しました",
     "An error occurred while trying to save the bookmark." : "ブックマークの保存を試している際にエラーが発生しました。",
     "Error" : "エラー",
